==> jc-1.4.0.tar.gz: gnu/java/security/ber/BEREncodingException.h <==
// public class gnu.java.security.ber.BEREncodingException

// class file dependencies
// @dep_class f1998ba7fba7cab7 gnu_java_security_ber_BEREncodingException
// @dep_class cafad05cb9c1e2a gnu_java_security_der_DEREncodingException
// @dep_class 4e0a56550c69d57c java_io_IOException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header gnu_java_security_der_DEREncodingException

#include "gnu/java/security/der/DEREncodingException.h"

#ifndef _JC_gnu_java_security_ber_BEREncodingException_H_
#define _JC_gnu_java_security_ber_BEREncodingException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_security_ber_BEREncodingException$sub_refs	_jc_gnu_java_security_ber_BEREncodingException$sub_refs;
typedef struct _jc_gnu_java_security_ber_BEREncodingException$sub_nonrefs	_jc_gnu_java_security_ber_BEREncodingException$sub_nonrefs;
typedef struct _jc_gnu_java_security_ber_BEREncodingException$refs	_jc_gnu_java_security_ber_BEREncodingException$refs;
typedef struct _jc_gnu_java_security_ber_BEREncodingException$nonrefs	_jc_gnu_java_security_ber_BEREncodingException$nonrefs;
typedef struct _jc_gnu_java_security_ber_BEREncodingException$object	_jc_gnu_java_security_ber_BEREncodingException$object;

typedef const struct _jc_gnu_java_security_ber_BEREncodingException$vmethods	_jc_gnu_java_security_ber_BEREncodingException$vmethods;
typedef const struct _jc_gnu_java_security_ber_BEREncodingException$vtable	_jc_gnu_java_security_ber_BEREncodingException$vtable;
typedef const struct _jc_gnu_java_security_ber_BEREncodingException$vtype	_jc_gnu_java_security_ber_BEREncodingException$vtype;

// Constructors
extern void _jc_gnu_java_security_ber_BEREncodingException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_security_ber_BEREncodingException$object *);
extern void _jc_gnu_java_security_ber_BEREncodingException$method$_init$c31b894660454d13(_jc_env *, struct _jc_gnu_java_security_ber_BEREncodingException$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_gnu_java_security_ber_BEREncodingException$vmethods {
};

// Vtable
struct _jc_gnu_java_security_ber_BEREncodingException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_io_IOException$vmethods	java_io_IOException;
	_jc_gnu_java_security_der_DEREncodingException$vmethods	gnu_java_security_der_DEREncodingException;
	_jc_gnu_java_security_ber_BEREncodingException$vmethods	gnu_java_security_ber_BEREncodingException;
};

// Vtype
struct _jc_gnu_java_security_ber_BEREncodingException$vtype {
	_jc_type			type;
	_jc_gnu_java_security_ber_BEREncodingException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_ber_BEREncodingException$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_security_ber_BEREncodingException$refs {
    _jc_gnu_java_security_ber_BEREncodingException$sub_refs	gnu_java_security_ber_BEREncodingException;
    _jc_gnu_java_security_der_DEREncodingException$sub_refs	gnu_java_security_der_DEREncodingException;
    _jc_java_io_IOException$sub_refs	java_io_IOException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_ber_BEREncodingException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_ber_BEREncodingException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_io_IOException$sub_nonrefs	java_io_IOException;
    _jc_gnu_java_security_der_DEREncodingException$sub_nonrefs	gnu_java_security_der_DEREncodingException;
    _jc_gnu_java_security_ber_BEREncodingException$sub_nonrefs	gnu_java_security_ber_BEREncodingException;
};

// Object instance structure
struct _jc_gnu_java_security_ber_BEREncodingException$object {
	_jc_gnu_java_security_ber_BEREncodingException$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_ber_BEREncodingException$vtype	*vtype;
	_jc_gnu_java_security_ber_BEREncodingException$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_ber_BEREncodingException$vtype _jc_gnu_java_security_ber_BEREncodingException$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_ber_BEREncodingException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_ber_BEREncodingException$class_object;

#endif	/* _JC_gnu_java_security_ber_BEREncodingException_H_ */

==> jc-1.4.6.tar.gz: gnu/java/security/ber/BEREncodingException.h <==
// public class gnu.java.security.ber.BEREncodingException

// class file dependencies
// @dep_class f1998ba7fba7cab7 gnu_java_security_ber_BEREncodingException
// @dep_class cafad05cb9c1e2a gnu_java_security_der_DEREncodingException
// @dep_class 4e0a56550c69d57c java_io_IOException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header gnu_java_security_der_DEREncodingException

#include "gnu/java/security/der/DEREncodingException.h"

#ifndef _JC_gnu_java_security_ber_BEREncodingException_H_
#define _JC_gnu_java_security_ber_BEREncodingException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_security_ber_BEREncodingException$sub_refs	_jc_gnu_java_security_ber_BEREncodingException$sub_refs;
typedef struct _jc_gnu_java_security_ber_BEREncodingException$sub_nonrefs	_jc_gnu_java_security_ber_BEREncodingException$sub_nonrefs;
typedef struct _jc_gnu_java_security_ber_BEREncodingException$refs	_jc_gnu_java_security_ber_BEREncodingException$refs;
typedef struct _jc_gnu_java_security_ber_BEREncodingException$nonrefs	_jc_gnu_java_security_ber_BEREncodingException$nonrefs;
typedef struct _jc_gnu_java_security_ber_BEREncodingException$object	_jc_gnu_java_security_ber_BEREncodingException$object;

typedef const struct _jc_gnu_java_security_ber_BEREncodingException$vmethods	_jc_gnu_java_security_ber_BEREncodingException$vmethods;
typedef const struct _jc_gnu_java_security_ber_BEREncodingException$vtable	_jc_gnu_java_security_ber_BEREncodingException$vtable;
typedef const struct _jc_gnu_java_security_ber_BEREncodingException$vtype	_jc_gnu_java_security_ber_BEREncodingException$vtype;

// Constructors
extern void _jc_gnu_java_security_ber_BEREncodingException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_security_ber_BEREncodingException$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_security_ber_BEREncodingException$method$_init$c31b894660454d13(_jc_env *, struct _jc_gnu_java_security_ber_BEREncodingException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_security_ber_BEREncodingException$vmethods {
};

// Vtable
struct _jc_gnu_java_security_ber_BEREncodingException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_io_IOException$vmethods	java_io_IOException;
	_jc_gnu_java_security_der_DEREncodingException$vmethods	gnu_java_security_der_DEREncodingException;
	_jc_gnu_java_security_ber_BEREncodingException$vmethods	gnu_java_security_ber_BEREncodingException;
};

// Vtype
struct _jc_gnu_java_security_ber_BEREncodingException$vtype {
	_jc_type			type;
	_jc_gnu_java_security_ber_BEREncodingException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_ber_BEREncodingException$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_security_ber_BEREncodingException$refs {
    _jc_gnu_java_security_ber_BEREncodingException$sub_refs	gnu_java_security_ber_BEREncodingException;
    _jc_gnu_java_security_der_DEREncodingException$sub_refs	gnu_java_security_der_DEREncodingException;
    _jc_java_io_IOException$sub_refs	java_io_IOException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_ber_BEREncodingException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_ber_BEREncodingException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_io_IOException$sub_nonrefs	java_io_IOException;
    _jc_gnu_java_security_der_DEREncodingException$sub_nonrefs	gnu_java_security_der_DEREncodingException;
    _jc_gnu_java_security_ber_BEREncodingException$sub_nonrefs	gnu_java_security_ber_BEREncodingException;
};

// Object instance structure
struct _jc_gnu_java_security_ber_BEREncodingException$object {
	_jc_gnu_java_security_ber_BEREncodingException$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_ber_BEREncodingException$vtype	*vtype;
	_jc_gnu_java_security_ber_BEREncodingException$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_ber_BEREncodingException$vtype _jc_gnu_java_security_ber_BEREncodingException$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_ber_BEREncodingException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_ber_BEREncodingException$class_object;

#endif	/* _JC_gnu_java_security_ber_BEREncodingException_H_ */
